@@ -5,12 +5,12 @@ app = typer.Typer()
 
 @app.command()
 def create(username: str):
-    typer.echo(f"Creating user: {username}")
+    print(f"Creating user: {username}")
 
 
 @app.command()
 def delete(username: str):
-    typer.echo(f"Deleting user: {username}")
+    print(f"Deleting user: {username}")
 
 
 if __name__ == "__main__":
