@@ -7,19 +7,19 @@ state = {"verbose": False}
 @app.command()
 def create(username: str):
     if state["verbose"]:
-        typer.echo("About to create a user")
-    typer.echo(f"Creating user: {username}")
+        print("About to create a user")
+    print(f"Creating user: {username}")
     if state["verbose"]:
-        typer.echo("Just created a user")
+        print("Just created a user")
 
 
 @app.command()
 def delete(username: str):
     if state["verbose"]:
-        typer.echo("About to delete a user")
-    typer.echo(f"Deleting user: {username}")
+        print("About to delete a user")
+    print(f"Deleting user: {username}")
     if state["verbose"]:
-        typer.echo("Just deleted a user")
+        print("Just deleted a user")
 
 
 @app.callback()
@@ -28,7 +28,7 @@ def main(verbose: bool = False):
     Manage users in the awesome CLI app.
     """
     if verbose:
-        typer.echo("Will write verbose output")
+        print("Will write verbose output")
         state["verbose"] = True
 
 
