@@ -5,12 +5,12 @@ app = typer.Typer()
 
 @app.command()
 def create(username: str):
-    typer.echo(f"Creating user: {username}")
+    print(f"Creating user: {username}")
 
 
 @app.command()
 def delete(username: str):
-    typer.echo(f"Deleting user: {username}")
+    print(f"Deleting user: {username}")
 
 
 @app.callback()
@@ -18,7 +18,7 @@ def main(ctx: typer.Context):
     """
     Manage users in the awesome CLI app.
     """
-    typer.echo(f"About to execute command: {ctx.invoked_subcommand}")
+    print(f"About to execute command: {ctx.invoked_subcommand}")
 
 
 if __name__ == "__main__":
