@@ -9,7 +9,7 @@ def main(
     )
 ):
     for name in names:
-        typer.echo(f"Hello {name}")
+        print(f"Hello {name}")
 
 
 if __name__ == "__main__":
