@@ -8,7 +8,7 @@ def name_callback(value: str):
 
 
 def main(name: str = typer.Option(..., callback=name_callback)):
-    typer.echo(f"Hello {name}")
+    print(f"Hello {name}")
 
 
 if __name__ == "__main__":
