@@ -2,14 +2,14 @@ import typer
 
 
 def name_callback(value: str):
-    typer.echo("Validating name")
+    print("Validating name")
     if value != "Camila":
         raise typer.BadParameter("Only Camila is allowed")
     return value
 
 
 def main(name: str = typer.Option(..., callback=name_callback)):
-    typer.echo(f"Hello {name}")
+    print(f"Hello {name}")
 
 
 if __name__ == "__main__":
