@@ -3,9 +3,9 @@ import typer
 
 def main(force: bool = typer.Option(False, "--force")):
     if force:
-        typer.echo("Forcing operation")
+        print("Forcing operation")
     else:
-        typer.echo("Not forcing")
+        print("Not forcing")
 
 
 if __name__ == "__main__":
