@@ -8,7 +8,7 @@ def main(
         ..., formats=["%Y-%m-%d", "%Y-%m-%dT%H:%M:%S", "%Y-%m-%d %H:%M:%S", "%m/%d/%Y"]
     )
 ):
-    typer.echo(f"Launch will be at: {launch_date}")
+    print(f"Launch will be at: {launch_date}")
 
 
 if __name__ == "__main__":
