@@ -1,5 +1,6 @@
 import os
 import subprocess
+import sys
 from pathlib import Path
 from unittest import mock
 
@@ -16,7 +17,7 @@ app.command()(mod.main)
 
 def test_completion_install_no_shell():
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--install-completion"],
+        [sys.executable, "-m", "coverage", "run", mod.__file__, "--install-completion"],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
@@ -39,7 +40,15 @@ def test_completion_install_bash():
     if bash_completion_path.is_file():
         text = bash_completion_path.read_text()
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--install-completion", "bash"],
+        [
+            sys.executable,
+            "-m",
+            "coverage",
+            "run",
+            mod.__file__,
+            "--install-completion",
+            "bash",
+        ],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
@@ -74,7 +83,15 @@ def test_completion_install_zsh():
     if completion_path.is_file():
         text = completion_path.read_text()
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--install-completion", "zsh"],
+        [
+            sys.executable,
+            "-m",
+            "coverage",
+            "run",
+            mod.__file__,
+            "--install-completion",
+            "zsh",
+        ],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
@@ -103,7 +120,15 @@ def test_completion_install_fish():
         Path.home() / f".config/fish/completions/{script_path.name}.fish"
     )
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--install-completion", "fish"],
+        [
+            sys.executable,
+            "-m",
+            "coverage",
+            "run",
+            mod.__file__,
+            "--install-completion",
+            "fish",
+        ],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
