@@ -1,4 +1,5 @@
 import subprocess
+import sys
 
 import typer
 import typer.core
@@ -41,7 +42,7 @@ def test_call_arg():
 
 def test_script():
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--help"],
+        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
