@@ -1,4 +1,5 @@
 import subprocess
+import sys
 
 from typer.testing import CliRunner
 
@@ -48,7 +49,7 @@ def test_delete():
 
 def test_script():
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--help"],
+        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
