@@ -1,4 +1,5 @@
 import subprocess
+import sys
 
 from docs_src.testing.app02 import main as mod
 from docs_src.testing.app02.test_main import test_app
@@ -10,7 +11,7 @@ def test_app02():
 
 def test_script():
     result = subprocess.run(
-        ["coverage", "run", mod.__file__, "--help"],
+        [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
         encoding="utf-8",
