@@ -1,7 +1,8 @@
 from enum import Enum
 from pathlib import Path
-from typing import List, Optional, Tuple
+from typing import Any, List, Optional, Tuple
 
+import click
 import pytest
 import typer
 from typer.testing import CliRunner
@@ -90,3 +91,40 @@ def test_tuple_parameter_elements_are_converted_recursively(type_annotation):
 
     result = runner.invoke(app, ["one", "two"])
     assert result.exit_code == 0
+
+
+def test_custom_parse():
+    app = typer.Typer()
+
+    @app.command()
+    def custom_parser(
+        hex_value: int = typer.Argument(None, parser=lambda x: int(x, 0))
+    ):
+        assert hex_value == 0x56
+
+    result = runner.invoke(app, ["0x56"])
+    assert result.exit_code == 0
+
+
+def test_custom_click_type():
+    class BaseNumberParamType(click.ParamType):
+        name = "base_integer"
+
+        def convert(
+            self,
+            value: Any,
+            param: Optional[click.Parameter],
+            ctx: Optional[click.Context],
+        ) -> Any:
+            return int(value, 0)
+
+    app = typer.Typer()
+
+    @app.command()
+    def custom_click_type(
+        hex_value: int = typer.Argument(None, click_type=BaseNumberParamType())
+    ):
+        assert hex_value == 0x56
+
+    result = runner.invoke(app, ["0x56"])
+    assert result.exit_code == 0
