@@ -71,12 +71,13 @@ COLOR_SYSTEM: Optional[
     Literal["auto", "standard", "256", "truecolor", "windows"]
 ] = "auto"  # Set to None to disable colors
 _TYPER_FORCE_DISABLE_TERMINAL = getenv("_TYPER_FORCE_DISABLE_TERMINAL")
-FORCE_TERMINAL = bool(
-    not _TYPER_FORCE_DISABLE_TERMINAL
-    and getenv("GITHUB_ACTIONS")
-    or getenv("FORCE_COLOR")
-    or getenv("PY_COLORS")
+FORCE_TERMINAL = (
+    True
+    if getenv("GITHUB_ACTIONS") or getenv("FORCE_COLOR") or getenv("PY_COLORS")
+    else None
 )
+if _TYPER_FORCE_DISABLE_TERMINAL:
+    FORCE_TERMINAL = False
 
 # Fixed strings
 DEPRECATED_STRING = "(deprecated) "
@@ -551,7 +552,6 @@ def rich_format_help(
 
     # Print command / group help if we have some
     if obj.help:
-
         # Print with some padding
         console.print(
             Padding(
@@ -568,7 +568,6 @@ def rich_format_help(
     panel_to_arguments: DefaultDict[str, List[click.Argument]] = defaultdict(list)
     panel_to_options: DefaultDict[str, List[click.Option]] = defaultdict(list)
     for param in obj.get_params(ctx):
-
         # Skip if option is hidden
         if getattr(param, "hidden", False):
             continue
